import setuptools

setuptools.setup(
    name="szl_gui",
    version="0.0.1",
    author="szl",
    author_email="1249268237@qq.com",
    description="",  #介绍
    long_description_content_type="text/markdown",
    url="https://github.com/",
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
)